<?php
/** -------------------------------------------------------------------------------
 *   ファイルシステム:ファイル排他制御のflockの利用例
 *  2015.09.16 作成 yoshi of CXMedia Inc.
 * -------------------------------------------------------------------------------- */
header("Content-type:text/plain; charset=UTF-8");

// カウント保存ファイルのパス
$filepath = 'data/count.txt';

// 「c+」モードでオープン（ファイルが存在しない場合には新規作成）
$fh = fopen( $filepath, "c+" );

// --- 排他ロックの開始 ---
@flock($fh,LOCK_EX);

/* -----------------------------------------------------------
 *  fgets ( handle [,length ] )
 *   handle で指定したファイルポインタから
 *    最大 length - 1 バイト読み出し、その文字列を返します。
 * ----------------------------------------------------------- */
// 9桁値の読み込みとカウントアップ
if( ($count = fgets($fh, 10)) ){
	$count++;
} else {
	// データなしのときの初期値設定
	$count = 1;
}
// ファイルポインタを先頭に戻す
rewind( $fh );

/* --------------------------------------------------------------------------
 *  fwrite ( handle ,string [,length ] )
 *   handle で指定したファイルポインタから、lengthバイト数分の文字列書き込み
 * -------------------------------------------------------------------------- */
// ファイルのカウント値の書き込み
if(!fwrite( $fh, $count)){
	echo "エラー：fwrite処理\n";
}

// --- ロックの解除 ---
flock($fh,LOCK_UN);

// ファイル閉じる
fclose( $fh );

// カウント値の表示
echo "■更新したカウント値：$count\n";
?>
